==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/osc/OSC_nl_NL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>Configureer OSC Plugin</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Universes Configuratie</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Universe</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Input Poort</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Output Adres</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Output Poort</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="80"/>
        <source>Inputs</source>
        <translation>Inputs</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="86"/>
        <source>Outputs</source>
        <translation>Outputs</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>Invalid IP</source>
        <translation>Ongeldig IP</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 is geen geldig IP.
Pas het IP Adres aan voordat u doorgaat.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="85"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Deze plugin verzorgt DMX output voor apparaten die het OSC transmissie protocol ondersteunen.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="136"/>
        <location filename="oscplugin.cpp" line="270"/>
        <source>Status: Not open</source>
        <translation>Status: Niet open</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="139"/>
        <location filename="oscplugin.cpp" line="273"/>
        <source>Status: Open</source>
        <translation>Status: Open</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="141"/>
        <source>Packets sent: </source>
        <translation>Pakketten verzonden:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="275"/>
        <source>Packets received: </source>
        <translation>Pakketten ontvangen:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="132"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="266"/>
        <source>Input</source>
        <translation>Input</translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.4.orig.tar.xz: qlcplus-QLC-_4.12.4/plugins/osc/OSC_nl_NL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>Configureer OSC Plugin</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Universes Configuratie</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Universe</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Input Poort</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Output Adres</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Output Poort</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="88"/>
        <source>Channel number calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="96"/>
        <source>OSC path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="106"/>
        <source>Channel number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="83"/>
        <source>Inputs</source>
        <translation>Inputs</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="89"/>
        <source>Outputs</source>
        <translation>Outputs</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>Invalid IP</source>
        <translation>Ongeldig IP</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 is geen geldig IP.
Pas het IP Adres aan voordat u doorgaat.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="91"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Deze plugin verzorgt DMX output voor apparaten die het OSC transmissie protocol ondersteunen.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="142"/>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Status: Not open</source>
        <translation>Status: Niet open</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="145"/>
        <location filename="oscplugin.cpp" line="279"/>
        <source>Status: Open</source>
        <translation>Status: Open</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <source>Packets sent: </source>
        <translation>Pakketten verzonden:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="281"/>
        <source>Packets received: </source>
        <translation>Pakketten ontvangen:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="138"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="272"/>
        <source>Input</source>
        <translation>Input</translation>
    </message>
</context>
</TS>
